<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="94"/>
        <source>MX Package Installer</source>
        <translation>Instalador e Desinstalador de Programas do MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Aplicativos Favoritos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <location filename="../mainwindow.cpp" line="97"/>
        <source>Package</source>
        <translation>Pacote</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <location filename="../mainwindow.cpp" line="97"/>
        <source>Info</source>
        <translation>Informação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="250"/>
        <location filename="../mainwindow.ui" line="657"/>
        <location filename="../mainwindow.ui" line="986"/>
        <location filename="../mainwindow.cpp" line="97"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <location filename="../mainwindow.ui" line="216"/>
        <location filename="../mainwindow.ui" line="623"/>
        <location filename="../mainwindow.ui" line="955"/>
        <location filename="../mainwindow.ui" line="1235"/>
        <source>search</source>
        <translation>procurar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="123"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Greyed out items have already been installed.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Instalador e Desinstalador de Programas Aplicativos do MX Linux&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Este programa é um gerenciador de pacotes do MX Linux, o nome original em inglês é &apos;&lt;b&gt;MX Package Installer&lt;/b&gt;&apos;.&lt;br&gt;Os itens sombreados indicam que os programas aplicativos já estão instalados.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>Stable Repo</source>
        <translation>Repositório Estável/Stable</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <location filename="../mainwindow.ui" line="568"/>
        <location filename="../mainwindow.ui" line="900"/>
        <location filename="../mainwindow.ui" line="1178"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filtrar os pacotes de acordo com seu estado.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="571"/>
        <location filename="../mainwindow.ui" line="575"/>
        <location filename="../mainwindow.ui" line="903"/>
        <location filename="../mainwindow.ui" line="907"/>
        <location filename="../mainwindow.cpp" line="2513"/>
        <source>All packages</source>
        <translation>Todos os pacotes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <location filename="../mainwindow.ui" line="580"/>
        <location filename="../mainwindow.ui" line="912"/>
        <location filename="../mainwindow.cpp" line="2526"/>
        <source>Installed</source>
        <translation>Instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <location filename="../mainwindow.ui" line="585"/>
        <location filename="../mainwindow.ui" line="917"/>
        <location filename="../mainwindow.cpp" line="2524"/>
        <source>Upgradable</source>
        <translation>Atualizáveis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="196"/>
        <location filename="../mainwindow.ui" line="590"/>
        <location filename="../mainwindow.ui" line="922"/>
        <location filename="../mainwindow.ui" line="1215"/>
        <location filename="../mainwindow.cpp" line="2498"/>
        <location filename="../mainwindow.cpp" line="2528"/>
        <location filename="../mainwindow.cpp" line="2619"/>
        <location filename="../mainwindow.cpp" line="2620"/>
        <source>Not installed</source>
        <translation>Não instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="240"/>
        <location filename="../mainwindow.ui" line="647"/>
        <location filename="../mainwindow.ui" line="976"/>
        <source>Package Name</source>
        <translation>Nome do Pacote</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <location filename="../mainwindow.ui" line="652"/>
        <location filename="../mainwindow.ui" line="981"/>
        <location filename="../mainwindow.ui" line="1270"/>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <location filename="../mainwindow.ui" line="684"/>
        <location filename="../mainwindow.ui" line="1043"/>
        <source>Total packages:</source>
        <translation>Total de pacotes:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="291"/>
        <location filename="../mainwindow.ui" line="698"/>
        <location filename="../mainwindow.ui" line="1050"/>
        <source>Hide library and developer packages</source>
        <translation>Ocultar pacotes de bibliotecas e de desenvolvedor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="313"/>
        <location filename="../mainwindow.ui" line="720"/>
        <location filename="../mainwindow.ui" line="1102"/>
        <source>Refresh list</source>
        <translation>Atualizar a lista</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="327"/>
        <location filename="../mainwindow.ui" line="734"/>
        <location filename="../mainwindow.ui" line="1022"/>
        <source>Installed:</source>
        <translation>Instalados:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="357"/>
        <location filename="../mainwindow.ui" line="764"/>
        <location filename="../mainwindow.ui" line="1015"/>
        <source>Upgradable:</source>
        <translation>Atualizáveis:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <location filename="../mainwindow.ui" line="791"/>
        <location filename="../mainwindow.ui" line="1083"/>
        <source>Also Install &quot;Recommended&quot; Packages</source>
        <translation>Instalar também pacotes &quot;recomendados&quot;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="394"/>
        <source>Remove orphan packages</source>
        <translation>Remover pacotes órfãos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="404"/>
        <location filename="../mainwindow.ui" line="1340"/>
        <source>Upgrade All</source>
        <translation>Atualizar Todos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <location filename="../mainwindow.ui" line="598"/>
        <location filename="../mainwindow.ui" line="930"/>
        <location filename="../mainwindow.ui" line="1497"/>
        <source>Greyed out items have already been installed.</source>
        <translation>Os itens sombreados já estão instalados.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <location filename="../mainwindow.ui" line="540"/>
        <location filename="../mainwindow.ui" line="867"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Upgradable package. Newer version available in selected repository.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Pacote atualizável. Versão mais recente disponível no repositório selecionado.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>MX Test Repo</source>
        <translation>Repositório de Teste/Test do MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="824"/>
        <source>Debian Backports</source>
        <translation>Repositório Debian Backports</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1157"/>
        <source>Flatpaks</source>
        <translation>Flatpaks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1181"/>
        <location filename="../mainwindow.ui" line="1185"/>
        <location filename="../mainwindow.cpp" line="2480"/>
        <source>All apps</source>
        <translation>Todos os aplicativos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1190"/>
        <location filename="../mainwindow.cpp" line="2484"/>
        <source>All runtimes</source>
        <translation>Todos os tempos de execução (runtimes)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1195"/>
        <location filename="../mainwindow.cpp" line="2488"/>
        <source>All available</source>
        <translation>Todos os disponíveis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1200"/>
        <location filename="../mainwindow.cpp" line="2478"/>
        <source>Installed apps</source>
        <translation>Aplicativos Instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1205"/>
        <location filename="../mainwindow.cpp" line="2476"/>
        <source>Installed runtimes</source>
        <translation>Runtimes instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1210"/>
        <location filename="../mainwindow.cpp" line="2496"/>
        <location filename="../mainwindow.cpp" line="2613"/>
        <location filename="../mainwindow.cpp" line="2614"/>
        <source>All installed</source>
        <translation>Tudo instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1260"/>
        <source>Short Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1265"/>
        <source>Full Package Name</source>
        <translation>Nome Completo do Pacote</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1275"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1319"/>
        <source>Total items </source>
        <translation>Total de Itenss:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1333"/>
        <source>Installed apps:</source>
        <translation>Aplicativos instalados:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1386"/>
        <source>Advanced</source>
        <translation>Avançado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1416"/>
        <source>Total installed size:</source>
        <translation>Espaço utilizado:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1430"/>
        <source>Remove unused runtimes</source>
        <translation>Remover o runtimes que não estiver sendo utilizado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1447"/>
        <location filename="../mainwindow.ui" line="1451"/>
        <source>For all users</source>
        <translation>Para todos os usuários</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1456"/>
        <source>For current user</source>
        <translation>Para o usuário atual</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1474"/>
        <source>Remote (repo):</source>
        <translation>Repositório (repo):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1517"/>
        <location filename="../mainwindow.cpp" line="2302"/>
        <location filename="../mainwindow.cpp" line="2436"/>
        <source>Console Output</source>
        <translation>Resultados em Console/Terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1523"/>
        <source>Enter</source>
        <translation>Inserir (Enter)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1534"/>
        <source>Respond here, or just press Enter</source>
        <translation>Responda aqui ou apenas pressione Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1590"/>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1597"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1613"/>
        <source>About this application</source>
        <translation>Sobre este aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1616"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1623"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1671"/>
        <source>Display help </source>
        <translation>Exibir ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1674"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1681"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1697"/>
        <location filename="../mainwindow.cpp" line="1072"/>
        <location filename="../mainwindow.cpp" line="2606"/>
        <location filename="../mainwindow.cpp" line="2610"/>
        <location filename="../mainwindow.cpp" line="2865"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1704"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1723"/>
        <source>Quit application</source>
        <translation>Sair do aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1726"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1733"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="176"/>
        <source>Uninstalling packages...</source>
        <translation>Desinstalando pacotes...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <source>Running pre-uninstall operations...</source>
        <translation>Executando operações pré-desinstalação...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="196"/>
        <source>Running post-uninstall operations...</source>
        <translation>Executando operações pós-desinstalação...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>Refreshing sources...</source>
        <translation>Atualizando as fontes...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="226"/>
        <location filename="../mainwindow.cpp" line="1120"/>
        <location filename="../mainwindow.cpp" line="1249"/>
        <location filename="../mainwindow.cpp" line="1387"/>
        <location filename="../mainwindow.cpp" line="1449"/>
        <location filename="../mainwindow.cpp" line="2120"/>
        <location filename="../mainwindow.cpp" line="2150"/>
        <location filename="../mainwindow.cpp" line="2162"/>
        <location filename="../mainwindow.cpp" line="2275"/>
        <location filename="../mainwindow.cpp" line="2294"/>
        <location filename="../mainwindow.cpp" line="2689"/>
        <location filename="../mainwindow.cpp" line="2765"/>
        <location filename="../mainwindow.cpp" line="2795"/>
        <location filename="../mainwindow.cpp" line="2888"/>
        <location filename="../mainwindow.cpp" line="2912"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="227"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>Houve um problema ao atualizar as fontes. Algumas fontes podem não ter fornecido atualizações. Para mais informação, verifique:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="619"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Please wait...</source>
        <translation>Por favor, espere...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="810"/>
        <location filename="../mainwindow.cpp" line="829"/>
        <source>Version </source>
        <translation>Versão</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="810"/>
        <source> in stable repo</source>
        <translation>no repositório estável/stable</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="812"/>
        <source>Not available in stable repo</source>
        <translation>Não disponível no repositório estável/stable</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="821"/>
        <location filename="../mainwindow.cpp" line="2413"/>
        <source>Latest version </source>
        <translation>Última versão </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="821"/>
        <location filename="../mainwindow.cpp" line="2413"/>
        <source> already installed</source>
        <translation>já instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="829"/>
        <source> installed</source>
        <translation>instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="940"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation>Você está prestes a usar o Repositório de Testes do MX que disponibiliza os pacotes apenas para teste. É possível que eles quebrem/danifiquem o seu sistema, por isso é recomendado que você faça um cópia de segurança (backup) do seu sistema e instale ou atualize apenas um pacote de cada vez. Se possível, nos informe no fórum, como foi a sua experiência com o pacote, para que ele seja avaliado e encaminhado para o Repositório Principal se for qualificado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="949"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>Você está prestes a usar o repositório do &apos;Debian Backports&apos; (atualizações retroportadas), que contém pacotes retirados do próximo lançamento do Debian (chamado &apos;teste&apos;/&apos;testing&apos;), adaptados e recompilados para uso na versão atual do Debian &apos;estável&apos;/&apos;stable&apos;. Esses pacotes não foram testados tão extensivamente como os das versões estáveis do Debian e do MX Linux, são fornecidos no estado em que se encontram ou &apos;como estão&apos;, com risco de incompatibilidade com outros componentes do Debian estável. Use com cuidado!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="957"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation>O MX Linux inclui este repositório de pacotes flatpaks, apenas para conveniência dos usuários, não é responsável pelo funcionamento dos próprios pacotes flatpaks. Para mais informações, consulte &apos;flatpaks&apos; no Wiki.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="964"/>
        <location filename="../mainwindow.cpp" line="2898"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="968"/>
        <source>Do not show this message again</source>
        <translation>Não exibir esta mensagem novamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1070"/>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1084"/>
        <source>The following packages were selected. Click Show Details for list of changes.</source>
        <translation>Os seguintes pacotes foram selecionados. Clique na opção Exibir Detalhes para ver a lista de alterações.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1121"/>
        <location filename="../mainwindow.cpp" line="1250"/>
        <location filename="../mainwindow.cpp" line="1450"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>Sem conexão com à Internet, não será possível baixar/descarregar/transferir a lista de pacotes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1126"/>
        <source>Installing packages...</source>
        <translation>Instalando pacotes...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1183"/>
        <source>Post-processing...</source>
        <translation>Pós-processamento...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1213"/>
        <source>Pre-processing for </source>
        <translation>Pré-processamento para</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1226"/>
        <source>Installing </source>
        <translation>Instalando</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1233"/>
        <source>Post-processing for </source>
        <translation>Pós-processamento para</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1388"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>Ocorreu um erro ao gravar o arquivo: %1. Por favor, verifique se você tem espaço livre suficiente no seu dispositivo de armazenamento</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1458"/>
        <source>Downloading package info...</source>
        <translation>Descarregando/baixando informações do pacote...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1912"/>
        <location filename="../mainwindow.cpp" line="1989"/>
        <location filename="../mainwindow.cpp" line="2013"/>
        <source>Package info</source>
        <translation>Informação do pacote</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1926"/>
        <location filename="../mainwindow.cpp" line="2831"/>
        <source>More &amp;info...</source>
        <translation>Mais &amp;informações...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1955"/>
        <source>Packages to be installed: </source>
        <translation>Pacotes a serem instalados:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2116"/>
        <location filename="../mainwindow.cpp" line="2129"/>
        <location filename="../mainwindow.cpp" line="2144"/>
        <location filename="../mainwindow.cpp" line="2159"/>
        <location filename="../mainwindow.cpp" line="2247"/>
        <location filename="../mainwindow.cpp" line="2270"/>
        <location filename="../mainwindow.cpp" line="2685"/>
        <location filename="../mainwindow.cpp" line="2759"/>
        <location filename="../mainwindow.cpp" line="2789"/>
        <location filename="../mainwindow.cpp" line="2882"/>
        <source>Done</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2116"/>
        <location filename="../mainwindow.cpp" line="2129"/>
        <location filename="../mainwindow.cpp" line="2144"/>
        <location filename="../mainwindow.cpp" line="2159"/>
        <location filename="../mainwindow.cpp" line="2247"/>
        <location filename="../mainwindow.cpp" line="2270"/>
        <location filename="../mainwindow.cpp" line="2288"/>
        <location filename="../mainwindow.cpp" line="2685"/>
        <location filename="../mainwindow.cpp" line="2759"/>
        <location filename="../mainwindow.cpp" line="2789"/>
        <location filename="../mainwindow.cpp" line="2882"/>
        <location filename="../mainwindow.cpp" line="2906"/>
        <source>Processing finished successfully.</source>
        <translation>Processamento concluído com sucesso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2121"/>
        <location filename="../mainwindow.cpp" line="2151"/>
        <location filename="../mainwindow.cpp" line="2163"/>
        <location filename="../mainwindow.cpp" line="2690"/>
        <location filename="../mainwindow.cpp" line="2766"/>
        <location filename="../mainwindow.cpp" line="2796"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>Detectado problema durante a instalação, verifique a informação (saída) no Terminal/Console.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2173"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2174"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2175"/>
        <source>Package Installer for MX Linux</source>
        <translation>Instalador e Desinstalador de Programas do MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2177"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2178"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2191"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2275"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation>Houve um problema ao desinstalar, verifique o resultado do procedimento.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2288"/>
        <location filename="../mainwindow.cpp" line="2906"/>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2294"/>
        <location filename="../mainwindow.cpp" line="2912"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>Houve um problema ao desinstalar o programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2387"/>
        <location filename="../mainwindow.cpp" line="2399"/>
        <source>Flatpak not installed</source>
        <translation>Flatpak não instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2388"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>O pacote Flatpak não está instalado.
Você gostaria de instalá-lo agora?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2399"/>
        <source>Flatpak was not installed</source>
        <translation>O Flatpak não foi instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2423"/>
        <location filename="../mainwindow.cpp" line="2445"/>
        <source>Flathub remote failed</source>
        <translation>Repositório Flathub falhou</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2423"/>
        <location filename="../mainwindow.cpp" line="2445"/>
        <source>Flathub remote could not be added</source>
        <translation>Repositório Flathub não pôde ser adicionado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2431"/>
        <source>Needs re-login</source>
        <translation>Precisa reiniciar a sessão (re-login)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2432"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>Você pode precisar sair da sessão e entrar novamente (logout/login) para ver os itens instalados no menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2606"/>
        <source>Upgrade</source>
        <translation>Atualizar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2718"/>
        <source>Quit?</source>
        <translation>Sair?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2719"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation>O processo ainda está em execução, sair agora pode deixar seu sistema inutilizável.&lt;p&gt;&lt;b&gt;Você tem certeza que deseja fechar o Instalador e Desinstalador de Programas do MX?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2863"/>
        <source>Reinstall</source>
        <translation>Reinstalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2889"/>
        <source>Problem detected during last operation, please inspect the console output.</source>
        <translation>Um problema foi detectado durante a última operação, por favor, inspecione a saída do console.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2899"/>
        <source>Potentially dangerous operation.
Please make sure you check carefully the list of packages to be removed.</source>
        <translation>Operação potencialmente perigosa.
Por favor, certifique-se de verificar cuidadosamente a lista de pacotes a ser removida.</translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="13"/>
        <source>Manage Flatpak Remotes</source>
        <translation>Gerenciar Repositórios Flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="22"/>
        <source>For all users</source>
        <translation>Para todos os usuários</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For current user</source>
        <translation>Para este usuário</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="29"/>
        <source>enter Flatpak remote URL</source>
        <translation>digite o endereço do repositório Flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="32"/>
        <source>enter Flatpakref location to install app</source>
        <translation>digite o endereço Flatpakref para instalar um aplicativo</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="34"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation>Adicione ou remova repositórios flatpak, ou instale aplicativos usando o endereço flatpakref</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="43"/>
        <source>Remove remote</source>
        <translation>Remover repositório</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="48"/>
        <source>Add remote</source>
        <translation>Adicionar repositório</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="53"/>
        <source>Install app</source>
        <translation>Instalar aplicativo</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="58"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="75"/>
        <source>Not removable</source>
        <translation>Não removível</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="76"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation>Flathub é o repositório principal de Flatpak&apos;s e não pode ser removido</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="96"/>
        <source>Error adding remote</source>
        <translation>Erro ao adicionar o repositório</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="97"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation>Não foi possível adicionar o repositório - o comando retornou um erro. Verifique o endereço do repositório e tente novamente.</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="102"/>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="102"/>
        <source>Remote added successfully</source>
        <translation>Repositório adicionado com sucesso</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Relatório de alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Parece que você está acessando com o usuário root, por favor, saia da sessão e entre novamente com o usuário normal para utilizar este programa.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>Unable to get exclusive lock</source>
        <translation>Não foi possível obter o bloqueio exclusivo</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="85"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>Outro aplicativo de gerenciamento de programas aplicativos ou pacotes (p. ex. Synaptic ou apt-get) está em execução. Feche primeiro o aplicativo em execução.</translation>
    </message>
</context>
</TS>
